# ToolChoiceFunction


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of the function | 

## Example

```python
from _generated.models.tool_choice_function import ToolChoiceFunction

# TODO update the JSON string below
json = "{}"
# create an instance of ToolChoiceFunction from a JSON string
tool_choice_function_instance = ToolChoiceFunction.from_json(json)
# print the JSON string representation of the object
print(ToolChoiceFunction.to_json())

# convert the object into a dict
tool_choice_function_dict = tool_choice_function_instance.to_dict()
# create an instance of ToolChoiceFunction from a dict
tool_choice_function_from_dict = ToolChoiceFunction.from_dict(tool_choice_function_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


